==> mrpt_2.1.7.orig.tar.gz: mrpt-2.1.7/apps/robot-map-gui/gui/observationTree/CPairNode.cpp <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          https://www.mrpt.org/                            |
   |                                                                           |
   | Copyright (c) 2005-2021, Individual contributors, see AUTHORS file        |
   | See: https://www.mrpt.org/Authors - All rights reserved.                  |
   | Released under BSD License. See details in https://www.mrpt.org/License   |
   +---------------------------------------------------------------------------+
   */
#include "CPairNode.h"

#include "CObservationsNode.h"
#include "CPosesNode.h"

using namespace mrpt;
using namespace mrpt::maps;

CPairNode::CPairNode(
	CNode* parent, const CSimpleMap::TPosePDFSensFramePair& poseSensFramePair,
	size_t indexInSimpleMap)
	: CNode(parent), m_indexInSimpleMap(indexInSimpleMap)
{
	mrpt::poses::CPose3D pos = poseSensFramePair.first->getMeanVal();
	m_pose = std::make_unique<CPosesNode>(this, pos);
	m_observations = std::make_unique<CObservationsNode>(
		this, poseSensFramePair.second, pos);
}

CPairNode::~CPairNode() = default;
int CPairNode::childCount() const { return 2; }
CNode* CPairNode::child(int id) { return getChild(id); }
CNode* CPairNode::child(int id) const { return getChild(id); }
CNode::ObjectType CPairNode::type() const
{
	return ObjectType::PosWithObservationPair;
}

std::string CPairNode::displayName() const
{
	return std::string("[") + std::to_string(m_indexInSimpleMap) +
		   std::string("] Pose-SF pair");
}
CNode* CPairNode::getChild(int id) const
{
	switch (id)
	{
		case 0:
			return m_pose.get();
		case 1:
			return m_observations.get();
		default:
			return nullptr;
	};
}

==> mrpt_2.2.0.orig.tar.gz: mrpt-2.2.0/apps/robot-map-gui/gui/observationTree/CPairNode.cpp <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          https://www.mrpt.org/                            |
   |                                                                           |
   | Copyright (c) 2005-2021, Individual contributors, see AUTHORS file        |
   | See: https://www.mrpt.org/Authors - All rights reserved.                  |
   | Released under BSD License. See details in https://www.mrpt.org/License   |
   +---------------------------------------------------------------------------+
   */
#include "CPairNode.h"

#include "CObservationsNode.h"
#include "CPosesNode.h"

using namespace mrpt;
using namespace mrpt::maps;

CPairNode::CPairNode(
	CNode* parent, const CSimpleMap::TPosePDFSensFramePair& poseSensFramePair,
	size_t indexInSimpleMap)
	: CNode(parent), m_indexInSimpleMap(indexInSimpleMap)
{
	mrpt::poses::CPose3D pos = poseSensFramePair.first->getMeanVal();
	m_pose = std::make_unique<CPosesNode>(this, pos);
	m_observations = std::make_unique<CObservationsNode>(
		this, poseSensFramePair.second, pos);
}

CPairNode::~CPairNode() = default;
int CPairNode::childCount() const { return 2; }
CNode* CPairNode::child(int id) { return getChild(id); }
CNode* CPairNode::child(int id) const { return getChild(id); }
CNode::ObjectType CPairNode::type() const
{
	return ObjectType::PosWithObservationPair;
}

std::string CPairNode::displayName() const
{
	return std::string("[") + std::to_string(m_indexInSimpleMap) +
		std::string("] Pose-SF pair");
}
CNode* CPairNode::getChild(int id) const
{
	switch (id)
	{
		case 0: return m_pose.get();
		case 1: return m_observations.get();
		default: return nullptr;
	};
}
